( cd usr/bin ; rm -rf ed )
( cd usr/bin ; ln -sf ../../bin/ed ed )
( cd usr/bin ; rm -rf red )
( cd usr/bin ; ln -sf ed red )
( cd usr/man/man1 ; rm -rf red.1.gz )
( cd usr/man/man1 ; ln -sf ed.1.gz red.1.gz )
( cd bin ; rm -rf red )
( cd bin ; ln -sf ed red )
